==> otrs-3.3.12.tar.bz2: otrs-3.3.12/bin/otrs.RegistrationUpdate.pl <==
#!/usr/bin/perl
# --
# bin/otrs.RegistrationUpdate.pl - rebuild config
# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
# --
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU AFFERO General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
# or see http://www.gnu.org/licenses/agpl.txt.
# --

use strict;
use warnings;

use File::Basename;
use FindBin qw($RealBin);
use lib dirname($RealBin);
use lib dirname($RealBin) . '/Kernel/cpan-lib';
use lib dirname($RealBin) . '/Custom';

use Kernel::Config;
use Kernel::System::Encode;
use Kernel::System::Time;
use Kernel::System::Log;
use Kernel::System::Main;
use Kernel::System::DB;
use Kernel::System::Registration;

print "otrs.RegistrationUpdate.pl - send system registration update\n";
print "Copyright (C) 2001-2015 OTRS AG, http://otrs.com/\n";

# ---
# common objects
# ---
my %CommonObject = ();
$CommonObject{ConfigObject} = Kernel::Config->new();
$CommonObject{EncodeObject} = Kernel::System::Encode->new(%CommonObject);
$CommonObject{LogObject}    = Kernel::System::Log->new(
    LogPrefix => 'OTRS-otrs.RegistrationUpdate.pl',
    %CommonObject,
);
$CommonObject{TimeObject}         = Kernel::System::Time->new(%CommonObject);
$CommonObject{MainObject}         = Kernel::System::Main->new(%CommonObject);
$CommonObject{DBObject}           = Kernel::System::DB->new(%CommonObject);
$CommonObject{RegistrationObject} = Kernel::System::Registration->new(%CommonObject);

my %RegistrationData = $CommonObject{RegistrationObject}->RegistrationDataGet();

if ( $RegistrationData{State} ne 'registered' ) {
    print STDERR "Error: this is not a registered system. Please register your system first.\n";
    exit 1;
}

my %Result = $CommonObject{RegistrationObject}->RegistrationUpdateSend();

if ( !$Result{Success} ) {
    print STDERR "Error: $Result{Reason}\n";
    exit 1;
}

print "Registration update was successfully sent.\n";
exit;

==> otrs-4.0.16.tar.bz2: otrs-4.0.16/bin/otrs.RegistrationUpdate.pl <==
#!/usr/bin/perl
# --
# bin/otrs.RegistrationUpdate.pl - rebuild config
# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
# --
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU AFFERO General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
# or see http://www.gnu.org/licenses/agpl.txt.
# --

use strict;
use warnings;

use File::Basename;
use FindBin qw($RealBin);
use lib dirname($RealBin);
use lib dirname($RealBin) . '/Kernel/cpan-lib';
use lib dirname($RealBin) . '/Custom';

use Kernel::System::ObjectManager;
use Kernel::System::Registration;

print "otrs.RegistrationUpdate.pl - send system registration update\n";
print "Copyright (C) 2001-2016 OTRS AG, http://otrs.com/\n";

# ---
# create object manager
# ---
local $Kernel::OM = Kernel::System::ObjectManager->new(
    'Kernel::System::Log' => {
        LogPrefix => 'OTRS-otrs.RegistrationUpdate.pl',
    },
);

my %RegistrationData = $Kernel::OM->Get('Kernel::System::Registration')->RegistrationDataGet();

if ( $RegistrationData{State} ne 'registered' ) {
    print STDERR "Error: this is not a registered system. Please register your system first.\n";
    exit 1;
}

my %Result = $Kernel::OM->Get('Kernel::System::Registration')->RegistrationUpdateSend();

if ( !$Result{Success} ) {
    print STDERR "Error: $Result{Reason}\n";
    exit 1;
}

print "Registration update was successfully sent.\n";
exit;
